@@ -1,5 +1,8 @@
 """The definition of the action for `python -m` command."""
-from sugar.cli import app
+
+from __future__ import annotations
+
+from sugar.cli import run_app
 
 if __name__ == '__main__':
-    app()
+    run_app()
